@@ -6,8 +6,8 @@
 ;; Author: Campbell Barton <ideasman42@gmail.com>
 
 ;; URL: https://codeberg.org/ideasman42/emacs-utimeclock
-;; Package-Version: 20251224.54
-;; Package-Revision: 1e071c7c57a5
+;; Package-Version: 20260108.1319
+;; Package-Revision: 210b417d1777
 ;; Package-Requires: ((emacs "29.1"))
 
 ;;; Commentary:
@@ -170,7 +170,7 @@ In this case the current time is used as the end time."
       (pcase-let ((`(,time-start ,time-end)
                    (save-match-data (split-string time-pair time-pair-sep))))
         (setq time-was-incomplete nil)
-        ;; `time-end' will be null when there was no `utimeclock-time-pair' separator.
+        ;; `time-end' will be nil when there was no `utimeclock-time-pair' separator.
         ;; Allow this for the end-string.
         (when (or (null time-end) (string-empty-p time-end))
           ;; We could make this optional.
@@ -498,7 +498,7 @@ ensure `utimeclock-time-prefix' text."
             (let ((prefix (utimeclock--time-point-previous-prefix time-pos)))
               (utimeclock--split-at-point prefix)))
            (t
-            (message "Can not split the line %S not found!" utimeclock-time-prefix))))))))
+            (message "Cannot split, time prefix %S not found!" utimeclock-time-prefix))))))))
 
 ;;;###autoload
 (defun utimeclock-show-summary ()
